@@ -12,7 +12,9 @@
 //!
 //! [Fornjot]: https://www.fornjot.app/
 
-#![deny(missing_docs)]
+#![warn(missing_docs)]
 
 pub mod debug;
+pub mod ext;
 pub mod mesh;
+pub mod processed_shape;
