@@ -11,9 +11,10 @@ pub trait SurfaceBuilder: Sized {
     fn from_axes(u: GlobalPath, v: impl Into<Vector<3>>) -> Self;
 
     /// Construct a plane from 3 points
-    fn plane_from_points(
+    fn update_as_plane_from_points(
+        &mut self,
         points: [impl Into<Point<3>>; 3],
-    ) -> (Self, [Point<2>; 3]);
+    ) -> [Point<2>; 3];
 }
 
 impl SurfaceBuilder for PartialSurface {
@@ -25,25 +26,19 @@ impl SurfaceBuilder for PartialSurface {
         }
     }
 
-    fn plane_from_points(
+    fn update_as_plane_from_points(
+        &mut self,
         points: [impl Into<Point<3>>; 3],
-    ) -> (Self, [Point<2>; 3]) {
+    ) -> [Point<2>; 3] {
         let [a, b, c] = points.map(Into::into);
 
         let (u, u_coords) = GlobalPath::line_from_points([a, b]);
         let v = c - a;
 
-        let coords = {
-            let [a, b] = u_coords.map(|point| point.t);
-            [[a, Scalar::ZERO], [b, Scalar::ZERO], [a, Scalar::ONE]]
-                .map(Point::from)
-        };
+        self.geometry = Some(SurfaceGeometry { u, v });
 
-        (
-            Self {
-                geometry: Some(SurfaceGeometry { u, v }),
-            },
-            coords,
-        )
+        let [a, b] = u_coords.map(|point| point.t);
+        [[a, Scalar::ZERO], [b, Scalar::ZERO], [a, Scalar::ONE]]
+            .map(Point::from)
     }
 }
