@@ -16,7 +16,7 @@ mod wrapper;
 
 pub use self::{
     objects::{
-        curve::{PartialCurve, PartialGlobalCurve},
+        curve::{MaybeSurfacePath, PartialCurve, PartialGlobalCurve},
         cycle::PartialCycle,
         edge::{PartialGlobalEdge, PartialHalfEdge},
         face::PartialFace,
@@ -24,7 +24,7 @@ pub use self::{
         sketch::PartialSketch,
         solid::PartialSolid,
         surface::PartialSurface,
-        vertex::{PartialGlobalVertex, PartialSurfaceVertex, PartialVertex},
+        vertex::{PartialGlobalVertex, PartialSurfaceVertex},
     },
     traits::{HasPartial, PartialObject},
     wrapper::{FullToPartialCache, Partial},
