@@ -1,8 +1,9 @@
 //! User input parsing and propagation.
 
+mod event;
 mod handler;
 mod movement;
 mod rotation;
 mod zoom;
 
-pub use self::handler::{Actions, Handler};
+pub use self::{event::InputEvent, handler::InputHandler};
